diff host/vamp-simple-host.cpp @ 73:6d16c376fd2f

* Make library name case-insensitive in PluginLoader * Some doc updates
author cannam
date Wed, 06 Jun 2007 12:49:55 +0000
parents 9d3272c7db60
children 94a42248ec33
line wrap: on
line diff
--- a/host/vamp-simple-host.cpp	Wed Jun 06 12:20:16 2007 +0000
+++ b/host/vamp-simple-host.cpp	Wed Jun 06 12:49:55 2007 +0000
@@ -78,13 +78,16 @@
         "  " << name << " pluginlibrary[." << PLUGIN_SUFFIX << "]:plugin[:output] file.wav\n"
         "  " << name << " pluginlibrary[." << PLUGIN_SUFFIX << "]:plugin file.wav [outputno]\n\n"
         "    -- Load plugin id \"plugin\" from \"pluginlibrary\" and run it on the\n"
-        "       audio data in \"file.wav\"; retrieve the named \"output\", or output\n"
-        "       number \"outputno\" (the first output by default) and dump it to\n"
+        "       audio data in \"file.wav\", retrieving the named \"output\", or output\n"
+        "       number \"outputno\" (the first output by default) and dumping it to\n"
         "       standard output.\n\n"
+        "       \"pluginlibrary\" should be a library name, not a file path; the\n"
+        "       standard Vamp library search path will be used to locate it.  If\n"
+        "       a file path is supplied, the directory part(s) will be ignored.\n\n"
         "  " << name << " -l\n\n"
-        "    -- List the plugin libraries and Vamp plugins in the plugin search path.\n\n"
+        "    -- List the plugin libraries and Vamp plugins in the library search path.\n\n"
         "  " << name << " -p\n\n"
-        "    -- Print out the Vamp plugin search path.\n\n"
+        "    -- Print out the Vamp library search path.\n\n"
         "  " << name << " -v\n\n"
         "    -- Display version information only.\n\n"
          << endl;